betty.extension.trees package - Betty 0.4.0a3 documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.extension.trees package

## Module contents

Provide interactive family trees by integrating Betty with Cytoscape.js.

final class betty.extension.trees.Trees

  Bases: `Extension`, `WebpackEntryPointProvider`

  Provide interactive family trees for use in web pages.

  Parameters:

    - project (`betty.project.Project`)

    - args (`typing.Any`)

    - kwargs (`typing.Any`)

  classmethod assets_directory_path() → pathlib.Path

    Return the path on disk where the extension’s assets are located.

    This may be anywhere in your Python package.

    Return type:

      `pathlib.Path`

  classmethod depends_on() → set[str]

    The extensions this one depends on, and comes after.

    Return type:

      `set`[`str`]

  classmethod plugin_description() → betty.locale.localizable.Localizable

    Get the human-readable long plugin description.

    Return type:

      `betty.locale.localizable.Localizable`

  classmethod plugin_id() → str

    Get the plugin ID.

    IDs are unique per plugin type: - A plugin repository MUST at most have a single plugin for any ID. - Different plugin repositories MAY each have a plugin with the same ID.

    Return type:

      `str`

  classmethod plugin_label() → betty.locale.localizable.Localizable

    Get the human-readable short plugin label.

    Return type:

      `betty.locale.localizable.Localizable`

  webpack_entry_point_cache_keys() → collections.abc.Sequence[str]

    Get the keys that make a Webpack build for this provider unique.

    Providers that can be cached regardless may `return ()`.

    Return type:

      `collections.abc.Sequence`[`str`]

  classmethod webpack_entry_point_directory_path() → pathlib.Path

    Get the path to the directory with the entry point assets.

    The directory must include at least a `package.json` and `main.ts`.

    Return type:

      `pathlib.Path`